normal_capitalization_for_name

Function normal_capitalization_for_name 

fn normal_capitalization_for_name(name: &str) -> bool
Check that the string only has capital letters at the start or after a space or hyphen