pub struct Localization {
check_langs: BitArray<[u16; 1], Lsb0>,
mod_langs: BitArray<[u16; 1], Lsb0>,
locas: Languages,
}Expand description
Database of all loaded localization keys and their values, for all supported languages.
Fields
check_langs: BitArray<[u16; 1], Lsb0>Which languages to check, according to the config file.
mod_langs: BitArray<[u16; 1], Lsb0>Which languages also actually exist in the mod.
This is used to not warn about missing loca when a mod doesn’t have the language at all.
(This saves them the effort of configuring check_langs).
locas: LanguagesDatabase of all localizations, indexed first by language and then by localization key.
Implementations
Sourceimpl Localization
impl Localization
fn iter_lang(&self) -> impl Iterator<Item = Language>
pub fn exists(&self, key: &str) -> bool
fn all_collision_keys( &self, lang: Language, ) -> TigerHashMap<u32, Vec<&LocaEntry>>
pub fn iter_keys(&self) -> impl Iterator<Item = &Token>
pub fn verify_exists_implied(&self, key: &str, token: &Token, max_sev: Severity)
pub fn verify_name_exists(&self, name: &Token, max_sev: Severity)
pub fn exists_lang(&self, key: &str, lang: Language) -> bool
pub fn verify_exists_lang(&self, token: &Token, lang: Option<Language>)
pub fn verify_exists_implied_lang( &self, key: &str, token: &Token, lang: Option<Language>, )
Sourcepub fn mark_used_return_exists(&self, key: &str) -> bool
pub fn mark_used_return_exists(&self, key: &str) -> bool
Marks a localization key as used for all languages.
Returns whether the key exists for any language (same as Localization::exists).
Sourcefn mark_used_return_missing(&self, key: &str) -> Vec<&'static str>
fn mark_used_return_missing(&self, key: &str) -> Vec<&'static str>
Marks a localization key as used for all languages.
Returns a Vec<&str> containing the languages for which the key does not exist.
Sourcefn mark_used_lang_return_exists(&self, key: &str, lang: Language) -> bool
fn mark_used_lang_return_exists(&self, key: &str, lang: Language) -> bool
Marks a localization key as used for one language.
Returns whether the key exists for this language (same as Localization::exists_lang).
pub fn suggest(&self, key: &str, token: &Token)
Sourcepub fn uses_macro(&self, key: &str, look_for: &str) -> bool
pub fn uses_macro(&self, key: &str, look_for: &str) -> bool
Return whether any language uses the given macro in its loca entry for this key. Only a macro at the top level of this entry counts; ones hidden recursively in other macros do not.
fn check_loca_code( value: &LocaValue, data: &Everything, sc: &mut ScopeContext, lang: Language, )
pub fn verify_key_has_options( &self, loca: &str, key: &Token, n: i64, prefix: &str, )
fn validate_loca<'b>( entry: &LocaEntry, from: &'b TigerHashMap<&'b str, LocaEntry>, data: &Everything, sc: &mut ScopeContext, lang: Language, )
pub fn validate_use(&self, key: &str, data: &Everything, sc: &mut ScopeContext)
fn check_collisions(&self, lang: Language)
pub fn validate_pass2(&self, data: &Everything)
pub fn mark_category_used(&self, prefix: &str)
pub fn check_unused(&self, _data: &Everything)
pub fn check_pod_loca(&self, data: &Everything)